package com.css.simulation.resource.scheduler.feign;

import api.common.pojo.common.ResponseBodyVO;
import api.common.pojo.param.KafkaParameter;
import api.common.pojo.param.MinioParameter;
import api.common.util.FileUtil;
import feign.Response;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.MediaType;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.InputStream;

@RestController
@RequestMapping("/demo")
public class DemoController {

    @Autowired
    private CommonService commonService;

    @PostMapping(value = "/upload", consumes = MediaType.MULTIPART_FORM_DATA_VALUE)
    public ResponseBodyVO<String> upload(@RequestPart("file") MultipartFile file,
                                         @RequestParam("objectName") String objectName) {

        return commonService.upload(file, objectName);
    }

    @PostMapping("/download")
    public void download(
            @RequestBody @Validated MinioParameter minioParameter,
            HttpServletResponse response
    ) throws IOException {
        Response download = commonService.download(minioParameter);
        Response.Body body = download.body();
        InputStream inputStream = body.asInputStream();
        FileUtil.downloadForHttp(minioParameter.getObjectName(), inputStream, response, 1024);
    }

    // -------------------------------- 带回调函数的发送 --------------------------------
    @PostMapping("/send")
    public ResponseBodyVO<String> send(@RequestBody @Validated KafkaParameter kafkaParameter) {
        return commonService.send(kafkaParameter);
    }

}
